function [N_res] = Nresfun(par,w)
% set up grid
par.ngridE 	    = 2;					   % # of grid point in prod
par.ngridK		= 100;					   % # of grid point in capital
par.ngridKp		= par.ngridK;			   % # of grid point in capital tmr
par.ngridState  = par.ngridE*par.ngridK;   % # of grid point in states

gridemin   = 0.8;                          % grid of prod
gridemax   = 1.2;
gridE      = [gridemin; gridemax]; 
transmatE  = [.75, .25; .25, .75 ];        % transition matrix of prod

gridkmin   = 0.1 * par.kRepSS;             % grid of capital
gridkmax   = 3   * par.kRepSS;
gridK      = linspace(gridkmin,gridkmax, par.ngridK)';      


% matE     = repmat(gridE, 1, par.ngridK); % auxiliary matrix (method 1)
% matK     = repmat(gridK, 1, par.ngridE)';

[matE,matK]  = ndgrid(gridE,gridK);        % auxiliary matrix (method 2)

% value function iteration
matN     = (par.nu .* matE .* matK .^ par.theta./w) .^ (1/(1-par.nu));
matPi    = matE .* matK .^ par.theta .* matN .^par.nu - w .* matN;

[arrayE, arrayK, arrayKp]  = ndgrid(gridE,gridK,gridK);    
arrayN   = (par.nu .* arrayE .* arrayK .^ par.theta./w) .^ (1/(1-par.nu));
arrayPi  = arrayE .* arrayK .^ par.theta .* arrayN .^par.nu - w .* arrayN;

matV     = matPi;                          % initial guess 
metrics  = 100;

while metrics > 1e-8
    
% % expected value (method 1)
% for ii = 1:par.ngridE
%     for jj = 1:par.ngridKp
%         arrayEV(ii,1,jj)=transmatE(ii,1)*matV(1,jj) + transmatE(ii,2)*matV(2,jj) ;
%     end
% end

% expected value (method 2)
arrayEV(:,1,:)  = transmatE*matV;

arrayVp  = arrayPi - (arrayKp - (1-par.delta) .* arrayK)  ...
           - (arrayKp > (1-par.delta+par.adj).* arrayK)* par.xi * w  ...
           - (arrayKp < (1-par.delta-par.adj).* arrayK)* par.xi * w  ...
           + par.beta * arrayEV;
       
[matVn,matidxKprime]  =  max(arrayVp,[],3);

metrics  = max(abs(matVn(:) - matV(:)));

matV     = 0.05*matV + 0.95*matVn;

end

% % verify if this is what we want
% a3 = squeeze( arrayVp(2, 10, : ) );
% a4 = matidxKprime(2, 10);

% figure(1)
% plot(gridK, matV(1,:))
% hold on 
% plot(gridK, matV(2,:))
% xlabel('Capital')
% ylabel('Value Function')
% legend({'\epsilon = 0.8','\epsilon = 1.2'})
% 
% figure(2)
% plot(gridK, gridK(matidxKprime(1,:)))
% hold on 
% plot(gridK, gridK(matidxKprime(2,:)))
% xlabel('Capital')
% ylabel('Capital Policy')
% legend({'\epsilon = 0.8','\epsilon = 1.2'})

%%
% transition matrix of distribution function (method 1) 
vecKprime     = matidxKprime(:);
transmatState = zeros(par.ngridState, par.ngridState);
for ii = 1:par.ngridState      % loop over combined grid today
    idxKprime = vecKprime(ii); % tomorrow's capital grid index
    idxE = (mod(ii,par.ngridE) == 0)*2 + (mod(ii,par.ngridE) ~=0 )*1;   % today's shock index    
    for jj = 1:par.ngridE      % loop over the shock tomorrow
        idxEprime = jj;        % tomorrow's shock index        
        idxStateprime = (idxKprime - 1)*par.ngridE + idxEprime;        % tomorrow's combined index
        transmatState(ii,idxStateprime) = transmatE(idxE, idxEprime);  % transition matrix in combined states
    end
end

matT   = transmatState';

vecDist = 1/par.ngridState*ones(par.ngridState,1);   % use uniform dist as starting value

metrics = 100;
n       = 1;
while metrics > 1e-10 && n < 1000
    
    vecDistprime = matT*vecDist;

    metrics = max(abs(vecDistprime - vecDist));
    
    vecDist = 0.1* vecDist + 0.9* vecDistprime;
    n       = n + 1;
end

matDist = reshape(vecDist, [par.ngridE, par.ngridK]);%Invariant Distribution

N_res=sum(matN(:).*matDist(:))-par.nSS;
end