% Clean up workspace
clear;
close;
clc;

%----------------------------------------------------------------
% Set parameters governing the model
%----------------------------------------------------------------

% Technology
par.theta 		= .21;								% capital coefficient
par.nu 			= .64;								% labor coefficient
par.delta 		= .10;								% depreciation (annual)
par.adj         = .05; 							    % no fixed cost region
par.xi          = .01;                              % fixed cost

% Preferences
par.beta 		= .96;								% discount factor (annual)
par.sigma 		= 1;								% coefficient of relative risk aversion (log utility)
par.phi 		= 1 / 1e5;						    % inverse Frisch elasticity of labor supply (linear)
par.nSS 		= .6;							    % hours worked in steady state

%----------------------------------------------------------------
% Set parameters governing approximations
%----------------------------------------------------------------

% Compute representative agent steady state (used in constructing the grids)
par.kRepSS 		= ((par.theta * (par.nSS ^par.nu)) / ((1 /par.beta) - (1 -par.delta))) ^ (1 / (1 - par.theta));
par.wRepSS 		= (par.kRepSS .^ par.theta) * par.nu * (par.nSS ^ (par.nu - 1));

save par par

