clear;
clc;

load par;

w = par.wRepSS;

% set up grid
par.ngridE 	    = 2;					   % # of grid point in prod
par.ngridK		= 100;					   % # of grid point in capital
par.ngridState  = par.ngridE*par.ngridK;   % # of grid point in states

gridemin   = 0.8;                          % grid of prod
gridemax   = 1.2;
gridE      = [gridemin; gridemax]; 
transmatE  = [.75, .25; .25, .75 ];        % transition matrix of prod

gridkmin   = 0.2 * par.kRepSS;             % grid of capital
gridkmax   = 5   * par.kRepSS;
gridK      = linspace(gridkmin,gridkmax, par.ngridK)';      

% matE     = repmat(gridE, 1, par.ngridK); % auxiliary matrix (method 1)
% matK     = repmat(gridK, 1, par.ngridE)';% auxiliary matrix (method 1)

[matE,matK]  = ndgrid(gridE,gridK);        % auxiliary matrix (method 2)
% [X1,X2,...,Xn] = ndgrid(x1,x2,...,xn) replicates the grid vectors x1,x2,...,xn to produce an n-dimensional full grid.
% value function iteration
matN     = (par.nu .* matE .* matK .^ par.theta./w) .^ (1/(1-par.nu));
matPi    = matE .* matK .^ par.theta .* matN .^par.nu - w .* matN;

[arrayE, arrayK, arrayKp]  = ndgrid(gridE,gridK,gridK);    
arrayN   = (par.nu .* arrayE .* arrayK .^ par.theta./w) .^ (1/(1-par.nu));
arrayPi  = arrayE .* arrayK .^ par.theta .* arrayN .^par.nu - w .* arrayN;

matV     = matPi;                          % initial guess 
metrics  = 100;

while metrics > 1e-8
    
% % expected value (method 1)
% for ii = 1:par.ngridE
%     for jj = 1:par.ngridKp
%         arrayEV(ii,1,jj)=transmatE(ii,1)*matV(1,jj) + transmatE(ii,2)*matV(2,jj) ;
%     end
% end

% expected value (method 2)
arrayEV(:,1,:)  = transmatE*matV; %ڵڶdimensionstack1

arrayVp  = arrayPi - (arrayKp - (1-par.delta) .* arrayK)  ...
           - (arrayKp > (1-par.delta+par.adj).* arrayK)* par.xi * w  ...
           - (arrayKp < (1-par.delta-par.adj).* arrayK)* par.xi * w  ...
           + par.beta * arrayEV;%The method for identity function!
       
[matVn,matidxKprime]  =  max(arrayVp,[],3);
% M = max(A,[],dim) returns the maximum element along dimension dim. 
% For example, if A is a matrix, then max(A,[],2) is a column vector containing the maximum value of each row.

metrics  = max(abs(matVn(:) - matV(:)));

matV     = 0.05*matV + 0.95*matVn;
end

% % verify if this is what we want
% a3 = squeeze( arrayVp(2, 10, : ) );
% a4 = matidxKprime(2, 10);

figure(1)
plot(gridK, matV(1,:))
hold on 
plot(gridK, matV(2,:))
xlabel('Capital')
ylabel('Value Function')
legend({'\epsilon = 0.8','\epsilon = 1.2'})

figure(2)
plot(gridK, gridK(matidxKprime(1,:)))
hold on 
plot(gridK, gridK(matidxKprime(2,:)))
xlabel('Capital')
ylabel('Capital Policy')
legend({'\epsilon = 0.8','\epsilon = 1.2'})